var $intro    = document.querySelector('#intro');
var $outro    = document.querySelector('#outro');
var $game     = document.querySelector('#game');
var $finished = document.querySelector('#finished');
var $teamStart = document.querySelector('#team-start');
var $credits  = document.querySelector('#credits');
var $instructions  = document.querySelector('#instructions');
var $loading  = document.querySelector('#loading');

var $summary = document.querySelector('.summary');

var $start    = document.querySelector('.start');
var $restart   = document.querySelector('.restart');
var $startNext  = document.querySelector('.start-next');
var $finalScore = document.querySelector('.final-score');
var $time    = document.querySelector('.time');
var $score   = document.querySelector('.score');
var $content = document.querySelector('.content');
var $svg     = document.querySelector('.svg');
var $exit     = document.querySelector('.exit');
var $yup     = document.querySelector('.yup');
var $next    = document.querySelector('.next');
var $team    = document.querySelector('.team');
var $showCredits  = document.querySelector('.credits');
var $showInstructions  = document.querySelector('.instructions');
var $hideCredits  = document.querySelector('.backCredits');
var $hideInstructions  = document.querySelector('.backInstructions');
var $transition    = document.querySelector('.transition');

var lang = 'fr';

var duration = 60;
var time     = duration;
var score    = 0;
var scores = [];

var icons = [];
var total = 99;

var team = '';
var interval;
var current = false;
var frozen = false;

var teamCount = 1;
var currentTeam = 0;

var bipSound;
var yupSound;
var nextSound;
var endSound;

function init() {
	bipSound = new Media('/android_asset/www/sounds/174721__drminky__watch-tick.wav');
	yupSound = new Media('/android_asset/www/sounds/131662__bertrof__game-sound-correct-v2.wav');
	nextSound = new Media('/android_asset/www/sounds/131657__bertrof__game-sound-wrong.wav');
	endSound = new Media('/android_asset/www/sounds/74983__spazzo-1493__jingle-4.wav');
	introSound = new Media('/android_asset/www/sounds/133054__cydon__jingle004.wav');

	introSound.play();

    buttons();
    intro();
}

function scene($el) {
	clearInterval(interval);
	$loading.className = 'hidden';
	$intro.className = 'hidden';
	$outro.className = 'hidden';
	$game.className = 'hidden';
	$teamStart.className = 'hidden';
	$finished.className = 'hidden';
	$credits.className = 'hidden';
	$instructions.className = 'hidden';
	$el.className = '';
}

function intro() {
	icons = [];

	clearInterval(interval);
	setContent($score, score);

	for (var i = 0; i <= total; i++) {
		icons.push('icon_' + i + '.svg');
	}

	showInterstitial();
	currentTeam = 0;
	scene($intro);
}

function teamStart() {
	currentTeam++;

	if (currentTeam > teamCount) {
		end();
		return;
	}

	$team.className = 'team team-' + currentTeam;

	var $nextTeam = document.querySelector('.next-team');
	$nextTeam.className = 'next-team team-' + currentTeam;

	var $nextTeamNumber = document.querySelector('.next-team-number');
	setContent($nextTeamNumber, currentTeam);

	scene($teamStart);
}

function start() {
	introSound.stop();
	endSound.play();

	current = false;

	time = duration;
	score = 0;

	clearInterval(interval);
	setContent($score, score);

	scene($game);

	tick();
	nextIcon();
}

function finished() {
	if ($summary.firstChild) {
		while ($summary.firstChild) {
			$summary.removeChild($summary.firstChild);
		}
	}

	for (var i = 1; i <= teamCount; i++) {
		var p = document.createElement('p');
		var span = document.createElement('span');
		span.className = 'team-' + i;
		p.appendChild(span);
		p.appendChild(document.createTextNode(' ' + scores[i]));
		$summary.appendChild(p);
	}

	scene($finished);

	endSound.play();
}

function end() {
	scores[currentTeam] = score;
	setContent($finalScore, score);

	if (currentTeam >= teamCount) {
		finished();
		return;
	}

	teamStart();
	endSound.play();
}

function nextIcon() {
	if (!icons.length) {
		end();
	}

	frozen = true;

	if (current === false) {
		setIcon();

		setTimeout(function() {
			$content.className = 'content in';
		}, 10);

		setTimeout(function() {
			frozen = false;
		}, 500);
	}
	else {
		$content.className = 'content';

		setTimeout(function() {
			$transition.className = 'transition in';
		}, 500);
		setTimeout(function() {
			$transition.className = 'transition';
		}, 2500);
		setTimeout(function() {
			setIcon();
			$content.className = 'content in';
		}, 3000);

		setTimeout(function() {
			frozen = false;
		}, 3500);
	}
}

function setIcon() {
	current = Math.floor(Math.random() * icons.length);
	var icon = icons[current];
	icons.splice(current, 1);

	$svg.style.backgroundImage = 'url(icons/' + icon + ')';
}

function buttons() {
	$yup.onclick = function() {
		if (frozen) return;
		score++;
		setContent($score, score);
		yupSound.play();
		nextIcon();
	};

	$next.onclick = function() {
		if (frozen) return;
		nextSound.play();
		nextIcon();
	};

	$exit.onclick = function() {
		if (confirm('Exit game ?')) {
			intro();
		}
	};

	$startNext.onclick = function() {
		teamStart();
	}

	$restart.onclick = function() {
		intro();
	}

	document.querySelector('.choose-1').onclick = function(event) {
		teamCount = this.getAttribute('data-count');
		teamStart();
	}

	document.querySelector('.choose-2').onclick = function(event) {
		teamCount = this.getAttribute('data-count');
		teamStart();
	}

	document.querySelector('.choose-3').onclick = function(event) {
		teamCount = this.getAttribute('data-count');
		teamStart();
	}

	document.querySelector('.choose-4').onclick = function(event) {
		teamCount = this.getAttribute('data-count');
		teamStart();
	}

	$showCredits.onclick = function() {
		scene($credits);
	}

	$showInstructions.onclick = function() {
		scene($instructions);
	}

	$hideCredits.onclick = function() {
		intro();
	}

	$hideInstructions.onclick = function() {
		intro();
	}

	$start.onclick = function(event) {
		start();
	}
}

function tick() {
	bipSound.play();
	setContent($time, time);
	time--;

	interval = setInterval(function() {
		bipSound.play();
		setContent($time, time);

		if (!time) {
			clearInterval(interval);
			end();
		}

		time--;
	}, 1000);
}

function setContent($el, value) {
	if ($el.firstChild) $el.removeChild($el.firstChild);
	$el.appendChild(document.createTextNode('' + value));
}